@@ -11,9 +11,14 @@ from datetime import date
 from DateTime import DateTime
 from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
+from collective.portlet.relateditems.relateditems import Renderer as RelatedItemsRenderer
+from plone.portlet.collection.collection import Renderer as CollectionPortletRenderer
 import re
 import time
 import json
+from zope.component import getMultiAdapter
+from Acquisition import aq_inner
+from ZTUtils import make_query
 
 try:
     from Products.PloneGetPaid.interfaces import IBuyableMarker
@@ -482,3 +487,33 @@ class TitleViewlet(ViewletBase):
             self.site_title = portal_title
         else:
             self.site_title = u"%s &larr; %s" % (page_title, portal_title)
+
+
+class RelatedItems(RelatedItemsRenderer, CommonBrowserView):
+    """
+    Overriding the related Items
+    """
+    _template = ViewPageTemplateFile('relateditems.pt')
+    
+    
+    def getAllRelatedItemsLink(self):
+        portal_state = getMultiAdapter((self.context, self.request),
+                                       name=u'plone_portal_state')
+        portal_url = portal_state.portal_url()
+        context = aq_inner(self.context)
+        req_items = {}
+        # make_query renders tuples literally, so let's make it a list
+        req_items['Subject'] = list(context.Subject())
+        if not self.data.show_all_types:
+            req_items['portal_type'] = list(self.data.allowed_types)
+        return '%s/@@search?%s' % (portal_url, make_query(req_items))
+    
+    
+class CollectionPortlet(CollectionPortletRenderer, CommonBrowserView):
+    """
+    Overriding the related Items
+    """
+    _template = ViewPageTemplateFile('collection.pt')
+    render = _template
+
+    
\ No newline at end of file
