@@ -22,6 +22,7 @@ from plone.i18n.normalizer.interfaces import IIDNormalizer
 from Products.CMFCore.utils import getToolByName
 from datetime import date
 from DateTime import DateTime
+import time
 
 
 class IYearListPortlet(IPortletDataProvider):
@@ -55,8 +56,16 @@ class Renderer(base.Renderer):
 
     @property
     def available(self):
-        return not self.context.restrictedTraverse('@@plone_context_state').is_view_template()
-       
+        return self.isEventPast(self.context)
+      
+    def isEventPast(self, event):
+        """
+        Checks if the event is already past
+        """
+        if event.portal_type != 'Event' and event.portal_type != 'Media Event':
+            return False
+        else:
+            return event.end() < time.time() 
     
     def css_class(self):
         return "portlet-yearListing"
